/* hw_irq.h: FR-V specific h/w IRQ stuff
 *
 * Copyright (C) 2003 Red Hat, Inc. All Rights Reserved.
 * Written by David Howells (dhowells@redhat.com)
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version
 * 2 of the License, or (at your option) any later version.
 */

#ifndef _ASM_HW_IRQ_H
#define _ASM_HW_IRQ_H


#endif /* _ASM_HW_IRQ_H */
